# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimServiceProviderConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimServiceProviderConfig - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'schemas': 'list[str]',
            'documentation_uri': 'str',
            'patch': 'ScimServiceProviderConfigSimpleFeature',
            'filter': 'ScimServiceProviderConfigFilterFeature',
            'etag': 'ScimServiceProviderConfigSimpleFeature',
            'sort': 'ScimServiceProviderConfigSimpleFeature',
            'bulk': 'ScimServiceProviderConfigBulkFeature',
            'change_password': 'ScimServiceProviderConfigSimpleFeature',
            'authentication_schemes': 'list[ScimServiceProviderConfigAuthenticationScheme]',
            'meta': 'ScimMetadata'
        }

        self.attribute_map = {
            'schemas': 'schemas',
            'documentation_uri': 'documentationUri',
            'patch': 'patch',
            'filter': 'filter',
            'etag': 'etag',
            'sort': 'sort',
            'bulk': 'bulk',
            'change_password': 'changePassword',
            'authentication_schemes': 'authenticationSchemes',
            'meta': 'meta'
        }

        self._schemas = None
        self._documentation_uri = None
        self._patch = None
        self._filter = None
        self._etag = None
        self._sort = None
        self._bulk = None
        self._change_password = None
        self._authentication_schemes = None
        self._meta = None

    @property
    def schemas(self):
        """
        Gets the schemas of this ScimServiceProviderConfig.
        The list of supported schemas.

        :return: The schemas of this ScimServiceProviderConfig.
        :rtype: list[str]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """
        Sets the schemas of this ScimServiceProviderConfig.
        The list of supported schemas.

        :param schemas: The schemas of this ScimServiceProviderConfig.
        :type: list[str]
        """
        
        self._schemas = schemas

    @property
    def documentation_uri(self):
        """
        Gets the documentation_uri of this ScimServiceProviderConfig.
        The HTTP-addressable URL that points to the service provider's documentation.

        :return: The documentation_uri of this ScimServiceProviderConfig.
        :rtype: str
        """
        return self._documentation_uri

    @documentation_uri.setter
    def documentation_uri(self, documentation_uri):
        """
        Sets the documentation_uri of this ScimServiceProviderConfig.
        The HTTP-addressable URL that points to the service provider's documentation.

        :param documentation_uri: The documentation_uri of this ScimServiceProviderConfig.
        :type: str
        """
        
        self._documentation_uri = documentation_uri

    @property
    def patch(self):
        """
        Gets the patch of this ScimServiceProviderConfig.
        The \"patch\" configuration options.

        :return: The patch of this ScimServiceProviderConfig.
        :rtype: ScimServiceProviderConfigSimpleFeature
        """
        return self._patch

    @patch.setter
    def patch(self, patch):
        """
        Sets the patch of this ScimServiceProviderConfig.
        The \"patch\" configuration options.

        :param patch: The patch of this ScimServiceProviderConfig.
        :type: ScimServiceProviderConfigSimpleFeature
        """
        
        self._patch = patch

    @property
    def filter(self):
        """
        Gets the filter of this ScimServiceProviderConfig.
        The \"filter\" configuration options.

        :return: The filter of this ScimServiceProviderConfig.
        :rtype: ScimServiceProviderConfigFilterFeature
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this ScimServiceProviderConfig.
        The \"filter\" configuration options.

        :param filter: The filter of this ScimServiceProviderConfig.
        :type: ScimServiceProviderConfigFilterFeature
        """
        
        self._filter = filter

    @property
    def etag(self):
        """
        Gets the etag of this ScimServiceProviderConfig.
        The \"etag\" configuration options.

        :return: The etag of this ScimServiceProviderConfig.
        :rtype: ScimServiceProviderConfigSimpleFeature
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """
        Sets the etag of this ScimServiceProviderConfig.
        The \"etag\" configuration options.

        :param etag: The etag of this ScimServiceProviderConfig.
        :type: ScimServiceProviderConfigSimpleFeature
        """
        
        self._etag = etag

    @property
    def sort(self):
        """
        Gets the sort of this ScimServiceProviderConfig.
        The \"sort\" configuration options.

        :return: The sort of this ScimServiceProviderConfig.
        :rtype: ScimServiceProviderConfigSimpleFeature
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """
        Sets the sort of this ScimServiceProviderConfig.
        The \"sort\" configuration options.

        :param sort: The sort of this ScimServiceProviderConfig.
        :type: ScimServiceProviderConfigSimpleFeature
        """
        
        self._sort = sort

    @property
    def bulk(self):
        """
        Gets the bulk of this ScimServiceProviderConfig.
        The \"bulk\" configuration options.

        :return: The bulk of this ScimServiceProviderConfig.
        :rtype: ScimServiceProviderConfigBulkFeature
        """
        return self._bulk

    @bulk.setter
    def bulk(self, bulk):
        """
        Sets the bulk of this ScimServiceProviderConfig.
        The \"bulk\" configuration options.

        :param bulk: The bulk of this ScimServiceProviderConfig.
        :type: ScimServiceProviderConfigBulkFeature
        """
        
        self._bulk = bulk

    @property
    def change_password(self):
        """
        Gets the change_password of this ScimServiceProviderConfig.
        The \"changePassword\" configuration options.

        :return: The change_password of this ScimServiceProviderConfig.
        :rtype: ScimServiceProviderConfigSimpleFeature
        """
        return self._change_password

    @change_password.setter
    def change_password(self, change_password):
        """
        Sets the change_password of this ScimServiceProviderConfig.
        The \"changePassword\" configuration options.

        :param change_password: The change_password of this ScimServiceProviderConfig.
        :type: ScimServiceProviderConfigSimpleFeature
        """
        
        self._change_password = change_password

    @property
    def authentication_schemes(self):
        """
        Gets the authentication_schemes of this ScimServiceProviderConfig.
        The list of supported authentication schemes.

        :return: The authentication_schemes of this ScimServiceProviderConfig.
        :rtype: list[ScimServiceProviderConfigAuthenticationScheme]
        """
        return self._authentication_schemes

    @authentication_schemes.setter
    def authentication_schemes(self, authentication_schemes):
        """
        Sets the authentication_schemes of this ScimServiceProviderConfig.
        The list of supported authentication schemes.

        :param authentication_schemes: The authentication_schemes of this ScimServiceProviderConfig.
        :type: list[ScimServiceProviderConfigAuthenticationScheme]
        """
        
        self._authentication_schemes = authentication_schemes

    @property
    def meta(self):
        """
        Gets the meta of this ScimServiceProviderConfig.
        The metadata of the SCIM resource.

        :return: The meta of this ScimServiceProviderConfig.
        :rtype: ScimMetadata
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """
        Sets the meta of this ScimServiceProviderConfig.
        The metadata of the SCIM resource.

        :param meta: The meta of this ScimServiceProviderConfig.
        :type: ScimMetadata
        """
        
        self._meta = meta

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class VoicemailUserPolicy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailUserPolicy - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'enabled': 'bool',
            'alert_timeout_seconds': 'int',
            'pin': 'str',
            'modified_date': 'datetime',
            'send_email_notifications': 'bool'
        }

        self.attribute_map = {
            'enabled': 'enabled',
            'alert_timeout_seconds': 'alertTimeoutSeconds',
            'pin': 'pin',
            'modified_date': 'modifiedDate',
            'send_email_notifications': 'sendEmailNotifications'
        }

        self._enabled = None
        self._alert_timeout_seconds = None
        self._pin = None
        self._modified_date = None
        self._send_email_notifications = None

    @property
    def enabled(self):
        """
        Gets the enabled of this VoicemailUserPolicy.
        Whether the user has voicemail enabled

        :return: The enabled of this VoicemailUserPolicy.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this VoicemailUserPolicy.
        Whether the user has voicemail enabled

        :param enabled: The enabled of this VoicemailUserPolicy.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def alert_timeout_seconds(self):
        """
        Gets the alert_timeout_seconds of this VoicemailUserPolicy.
        The number of seconds to ring the user's phone before a call is transfered to voicemail

        :return: The alert_timeout_seconds of this VoicemailUserPolicy.
        :rtype: int
        """
        return self._alert_timeout_seconds

    @alert_timeout_seconds.setter
    def alert_timeout_seconds(self, alert_timeout_seconds):
        """
        Sets the alert_timeout_seconds of this VoicemailUserPolicy.
        The number of seconds to ring the user's phone before a call is transfered to voicemail

        :param alert_timeout_seconds: The alert_timeout_seconds of this VoicemailUserPolicy.
        :type: int
        """
        
        self._alert_timeout_seconds = alert_timeout_seconds

    @property
    def pin(self):
        """
        Gets the pin of this VoicemailUserPolicy.
        The user's PIN to access their voicemail. This property is only used for updates and never provided otherwise to ensure security

        :return: The pin of this VoicemailUserPolicy.
        :rtype: str
        """
        return self._pin

    @pin.setter
    def pin(self, pin):
        """
        Sets the pin of this VoicemailUserPolicy.
        The user's PIN to access their voicemail. This property is only used for updates and never provided otherwise to ensure security

        :param pin: The pin of this VoicemailUserPolicy.
        :type: str
        """
        
        self._pin = pin

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailUserPolicy.
        The date the policy was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified_date of this VoicemailUserPolicy.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailUserPolicy.
        The date the policy was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified_date: The modified_date of this VoicemailUserPolicy.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def send_email_notifications(self):
        """
        Gets the send_email_notifications of this VoicemailUserPolicy.
        Whether email notifications are sent to the user when a new voicemail is received

        :return: The send_email_notifications of this VoicemailUserPolicy.
        :rtype: bool
        """
        return self._send_email_notifications

    @send_email_notifications.setter
    def send_email_notifications(self, send_email_notifications):
        """
        Sets the send_email_notifications of this VoicemailUserPolicy.
        Whether email notifications are sent to the user when a new voicemail is received

        :param send_email_notifications: The send_email_notifications of this VoicemailUserPolicy.
        :type: bool
        """
        
        self._send_email_notifications = send_email_notifications

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Email(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Email - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'held': 'bool',
            'subject': 'str',
            'messages_sent': 'int',
            'segments': 'list[Segment]',
            'direction': 'str',
            'recording_id': 'str',
            'error_info': 'ErrorBody',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'start_alerting_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'auto_generated': 'bool',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'message_id': 'str',
            'draft_attachments': 'list[Attachment]',
            'spam': 'bool',
            'wrapup': 'Wrapup',
            'after_call_work': 'AfterCallWork',
            'after_call_work_required': 'bool'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'held': 'held',
            'subject': 'subject',
            'messages_sent': 'messagesSent',
            'segments': 'segments',
            'direction': 'direction',
            'recording_id': 'recordingId',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'start_alerting_time': 'startAlertingTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'auto_generated': 'autoGenerated',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'message_id': 'messageId',
            'draft_attachments': 'draftAttachments',
            'spam': 'spam',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired'
        }

        self._state = None
        self._id = None
        self._held = None
        self._subject = None
        self._messages_sent = None
        self._segments = None
        self._direction = None
        self._recording_id = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._start_alerting_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._auto_generated = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._message_id = None
        self._draft_attachments = None
        self._spam = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None

    @property
    def state(self):
        """
        Gets the state of this Email.
        The connection state of this communication.

        :return: The state of this Email.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Email.
        The connection state of this communication.

        :param state: The state of this Email.
        :type: str
        """
        allowed_values = ["alerting", "connected", "disconnected", "none", "transmitting"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def id(self):
        """
        Gets the id of this Email.
        A globally unique identifier for this communication.

        :return: The id of this Email.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Email.
        A globally unique identifier for this communication.

        :param id: The id of this Email.
        :type: str
        """
        
        self._id = id

    @property
    def held(self):
        """
        Gets the held of this Email.
        True if this call is held and the person on this side hears silence.

        :return: The held of this Email.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this Email.
        True if this call is held and the person on this side hears silence.

        :param held: The held of this Email.
        :type: bool
        """
        
        self._held = held

    @property
    def subject(self):
        """
        Gets the subject of this Email.
        The subject for the initial email that started this conversation.

        :return: The subject of this Email.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this Email.
        The subject for the initial email that started this conversation.

        :param subject: The subject of this Email.
        :type: str
        """
        
        self._subject = subject

    @property
    def messages_sent(self):
        """
        Gets the messages_sent of this Email.
        The number of email messages sent by this participant.

        :return: The messages_sent of this Email.
        :rtype: int
        """
        return self._messages_sent

    @messages_sent.setter
    def messages_sent(self, messages_sent):
        """
        Sets the messages_sent of this Email.
        The number of email messages sent by this participant.

        :param messages_sent: The messages_sent of this Email.
        :type: int
        """
        
        self._messages_sent = messages_sent

    @property
    def segments(self):
        """
        Gets the segments of this Email.
        The time line of the participant's email, divided into activity segments.

        :return: The segments of this Email.
        :rtype: list[Segment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this Email.
        The time line of the participant's email, divided into activity segments.

        :param segments: The segments of this Email.
        :type: list[Segment]
        """
        
        self._segments = segments

    @property
    def direction(self):
        """
        Gets the direction of this Email.
        The direction of the email

        :return: The direction of this Email.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this Email.
        The direction of the email

        :param direction: The direction of this Email.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def recording_id(self):
        """
        Gets the recording_id of this Email.
        A globally unique identifier for the recording associated with this call.

        :return: The recording_id of this Email.
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """
        Sets the recording_id of this Email.
        A globally unique identifier for the recording associated with this call.

        :param recording_id: The recording_id of this Email.
        :type: str
        """
        
        self._recording_id = recording_id

    @property
    def error_info(self):
        """
        Gets the error_info of this Email.


        :return: The error_info of this Email.
        :rtype: ErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this Email.


        :param error_info: The error_info of this Email.
        :type: ErrorBody
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Email.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :return: The disconnect_type of this Email.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Email.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :param disconnect_type: The disconnect_type of this Email.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "timeout", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this Email.
        The timestamp the email was placed on hold in the cloud clock if the email is currently on hold. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_hold_time of this Email.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this Email.
        The timestamp the email was placed on hold in the cloud clock if the email is currently on hold. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_hold_time: The start_hold_time of this Email.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def start_alerting_time(self):
        """
        Gets the start_alerting_time of this Email.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_alerting_time of this Email.
        :rtype: datetime
        """
        return self._start_alerting_time

    @start_alerting_time.setter
    def start_alerting_time(self, start_alerting_time):
        """
        Sets the start_alerting_time of this Email.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_alerting_time: The start_alerting_time of this Email.
        :type: datetime
        """
        
        self._start_alerting_time = start_alerting_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Email.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The connected_time of this Email.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Email.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param connected_time: The connected_time of this Email.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Email.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The disconnected_time of this Email.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Email.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param disconnected_time: The disconnected_time of this Email.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def auto_generated(self):
        """
        Gets the auto_generated of this Email.
        Indicates that the email was auto-generated like an Out of Office reply.

        :return: The auto_generated of this Email.
        :rtype: bool
        """
        return self._auto_generated

    @auto_generated.setter
    def auto_generated(self, auto_generated):
        """
        Sets the auto_generated of this Email.
        Indicates that the email was auto-generated like an Out of Office reply.

        :param auto_generated: The auto_generated of this Email.
        :type: bool
        """
        
        self._auto_generated = auto_generated

    @property
    def provider(self):
        """
        Gets the provider of this Email.
        The source provider for the email.

        :return: The provider of this Email.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this Email.
        The source provider for the email.

        :param provider: The provider of this Email.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this Email.
        The UUID of the script to use.

        :return: The script_id of this Email.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this Email.
        The UUID of the script to use.

        :param script_id: The script_id of this Email.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this Email.
        The id of the peer communication corresponding to a matching leg for this communication.

        :return: The peer_id of this Email.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this Email.
        The id of the peer communication corresponding to a matching leg for this communication.

        :param peer_id: The peer_id of this Email.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def message_id(self):
        """
        Gets the message_id of this Email.
        A globally unique identifier for the stored content of this communication.

        :return: The message_id of this Email.
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """
        Sets the message_id of this Email.
        A globally unique identifier for the stored content of this communication.

        :param message_id: The message_id of this Email.
        :type: str
        """
        
        self._message_id = message_id

    @property
    def draft_attachments(self):
        """
        Gets the draft_attachments of this Email.
        A list of uploaded attachments on the email draft.

        :return: The draft_attachments of this Email.
        :rtype: list[Attachment]
        """
        return self._draft_attachments

    @draft_attachments.setter
    def draft_attachments(self, draft_attachments):
        """
        Sets the draft_attachments of this Email.
        A list of uploaded attachments on the email draft.

        :param draft_attachments: The draft_attachments of this Email.
        :type: list[Attachment]
        """
        
        self._draft_attachments = draft_attachments

    @property
    def spam(self):
        """
        Gets the spam of this Email.
        Indicates if the inbound email was marked as spam.

        :return: The spam of this Email.
        :rtype: bool
        """
        return self._spam

    @spam.setter
    def spam(self, spam):
        """
        Sets the spam of this Email.
        Indicates if the inbound email was marked as spam.

        :param spam: The spam of this Email.
        :type: bool
        """
        
        self._spam = spam

    @property
    def wrapup(self):
        """
        Gets the wrapup of this Email.
        Call wrap up or disposition data.

        :return: The wrapup of this Email.
        :rtype: Wrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this Email.
        Call wrap up or disposition data.

        :param wrapup: The wrapup of this Email.
        :type: Wrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this Email.
        After-call work for the communication.

        :return: The after_call_work of this Email.
        :rtype: AfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this Email.
        After-call work for the communication.

        :param after_call_work: The after_call_work of this Email.
        :type: AfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this Email.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :return: The after_call_work_required of this Email.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this Email.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :param after_call_work_required: The after_call_work_required of this Email.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserDevice(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserDevice - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'device_token': 'str',
            'notification_id': 'str',
            'make': 'str',
            'model': 'str',
            'accept_notifications': 'bool',
            'type': 'str',
            'session_hash': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'device_token': 'deviceToken',
            'notification_id': 'notificationId',
            'make': 'make',
            'model': 'model',
            'accept_notifications': 'acceptNotifications',
            'type': 'type',
            'session_hash': 'sessionHash',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._device_token = None
        self._notification_id = None
        self._make = None
        self._model = None
        self._accept_notifications = None
        self._type = None
        self._session_hash = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this UserDevice.
        The globally unique identifier for the object.

        :return: The id of this UserDevice.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserDevice.
        The globally unique identifier for the object.

        :param id: The id of this UserDevice.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this UserDevice.


        :return: The name of this UserDevice.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserDevice.


        :param name: The name of this UserDevice.
        :type: str
        """
        
        self._name = name

    @property
    def device_token(self):
        """
        Gets the device_token of this UserDevice.
        device token sent by mobile clients.

        :return: The device_token of this UserDevice.
        :rtype: str
        """
        return self._device_token

    @device_token.setter
    def device_token(self, device_token):
        """
        Sets the device_token of this UserDevice.
        device token sent by mobile clients.

        :param device_token: The device_token of this UserDevice.
        :type: str
        """
        
        self._device_token = device_token

    @property
    def notification_id(self):
        """
        Gets the notification_id of this UserDevice.
        notification id of the device.

        :return: The notification_id of this UserDevice.
        :rtype: str
        """
        return self._notification_id

    @notification_id.setter
    def notification_id(self, notification_id):
        """
        Sets the notification_id of this UserDevice.
        notification id of the device.

        :param notification_id: The notification_id of this UserDevice.
        :type: str
        """
        
        self._notification_id = notification_id

    @property
    def make(self):
        """
        Gets the make of this UserDevice.
        make of the device.

        :return: The make of this UserDevice.
        :rtype: str
        """
        return self._make

    @make.setter
    def make(self, make):
        """
        Sets the make of this UserDevice.
        make of the device.

        :param make: The make of this UserDevice.
        :type: str
        """
        
        self._make = make

    @property
    def model(self):
        """
        Gets the model of this UserDevice.
        Device model

        :return: The model of this UserDevice.
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """
        Sets the model of this UserDevice.
        Device model

        :param model: The model of this UserDevice.
        :type: str
        """
        
        self._model = model

    @property
    def accept_notifications(self):
        """
        Gets the accept_notifications of this UserDevice.
        if the device accepts notifications

        :return: The accept_notifications of this UserDevice.
        :rtype: bool
        """
        return self._accept_notifications

    @accept_notifications.setter
    def accept_notifications(self, accept_notifications):
        """
        Sets the accept_notifications of this UserDevice.
        if the device accepts notifications

        :param accept_notifications: The accept_notifications of this UserDevice.
        :type: bool
        """
        
        self._accept_notifications = accept_notifications

    @property
    def type(self):
        """
        Gets the type of this UserDevice.
        type of the device; ios or android

        :return: The type of this UserDevice.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this UserDevice.
        type of the device; ios or android

        :param type: The type of this UserDevice.
        :type: str
        """
        allowed_values = ["android", "ios"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def session_hash(self):
        """
        Gets the session_hash of this UserDevice.


        :return: The session_hash of this UserDevice.
        :rtype: str
        """
        return self._session_hash

    @session_hash.setter
    def session_hash(self, session_hash):
        """
        Sets the session_hash of this UserDevice.


        :param session_hash: The session_hash of this UserDevice.
        :type: str
        """
        
        self._session_hash = session_hash

    @property
    def self_uri(self):
        """
        Gets the self_uri of this UserDevice.
        The URI for this object

        :return: The self_uri of this UserDevice.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this UserDevice.
        The URI for this object

        :param self_uri: The self_uri of this UserDevice.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SingleWorkdayAverageValues(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SingleWorkdayAverageValues - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'date_workday': 'date',
            'division': 'Division',
            'user': 'UserReference',
            'timezone': 'str',
            'results': 'list[WorkdayValuesMetricItem]'
        }

        self.attribute_map = {
            'date_workday': 'dateWorkday',
            'division': 'division',
            'user': 'user',
            'timezone': 'timezone',
            'results': 'results'
        }

        self._date_workday = None
        self._division = None
        self._user = None
        self._timezone = None
        self._results = None

    @property
    def date_workday(self):
        """
        Gets the date_workday of this SingleWorkdayAverageValues.
        The targeted workday for average value query. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :return: The date_workday of this SingleWorkdayAverageValues.
        :rtype: date
        """
        return self._date_workday

    @date_workday.setter
    def date_workday(self, date_workday):
        """
        Sets the date_workday of this SingleWorkdayAverageValues.
        The targeted workday for average value query. Dates are represented as an ISO-8601 string. For example: yyyy-MM-dd

        :param date_workday: The date_workday of this SingleWorkdayAverageValues.
        :type: date
        """
        
        self._date_workday = date_workday

    @property
    def division(self):
        """
        Gets the division of this SingleWorkdayAverageValues.
        The targeted division for the metrics

        :return: The division of this SingleWorkdayAverageValues.
        :rtype: Division
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this SingleWorkdayAverageValues.
        The targeted division for the metrics

        :param division: The division of this SingleWorkdayAverageValues.
        :type: Division
        """
        
        self._division = division

    @property
    def user(self):
        """
        Gets the user of this SingleWorkdayAverageValues.
        The targeted user for the metrics

        :return: The user of this SingleWorkdayAverageValues.
        :rtype: UserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this SingleWorkdayAverageValues.
        The targeted user for the metrics

        :param user: The user of this SingleWorkdayAverageValues.
        :type: UserReference
        """
        
        self._user = user

    @property
    def timezone(self):
        """
        Gets the timezone of this SingleWorkdayAverageValues.
        The time zone used for aggregating metric values

        :return: The timezone of this SingleWorkdayAverageValues.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this SingleWorkdayAverageValues.
        The time zone used for aggregating metric values

        :param timezone: The timezone of this SingleWorkdayAverageValues.
        :type: str
        """
        
        self._timezone = timezone

    @property
    def results(self):
        """
        Gets the results of this SingleWorkdayAverageValues.
        The metric value averages

        :return: The results of this SingleWorkdayAverageValues.
        :rtype: list[WorkdayValuesMetricItem]
        """
        return self._results

    @results.setter
    def results(self, results):
        """
        Sets the results of this SingleWorkdayAverageValues.
        The metric value averages

        :param results: The results of this SingleWorkdayAverageValues.
        :type: list[WorkdayValuesMetricItem]
        """
        
        self._results = results

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class RecordingJobsQuery(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RecordingJobsQuery - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'action': 'str',
            'action_date': 'datetime',
            'integration_id': 'str',
            'include_screen_recordings': 'bool',
            'conversation_query': 'AsyncConversationQuery'
        }

        self.attribute_map = {
            'action': 'action',
            'action_date': 'actionDate',
            'integration_id': 'integrationId',
            'include_screen_recordings': 'includeScreenRecordings',
            'conversation_query': 'conversationQuery'
        }

        self._action = None
        self._action_date = None
        self._integration_id = None
        self._include_screen_recordings = None
        self._conversation_query = None

    @property
    def action(self):
        """
        Gets the action of this RecordingJobsQuery.
        Operation to perform bulk task

        :return: The action of this RecordingJobsQuery.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this RecordingJobsQuery.
        Operation to perform bulk task

        :param action: The action of this RecordingJobsQuery.
        :type: str
        """
        allowed_values = ["DELETE", "EXPORT"]
        if action.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action -> " + action)
            self._action = "outdated_sdk_version"
        else:
            self._action = action

    @property
    def action_date(self):
        """
        Gets the action_date of this RecordingJobsQuery.
        The date when the action will be performed. If the operation will cause the delete date of a recording to be older than the export date, the export date will be adjusted to the delete date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The action_date of this RecordingJobsQuery.
        :rtype: datetime
        """
        return self._action_date

    @action_date.setter
    def action_date(self, action_date):
        """
        Sets the action_date of this RecordingJobsQuery.
        The date when the action will be performed. If the operation will cause the delete date of a recording to be older than the export date, the export date will be adjusted to the delete date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param action_date: The action_date of this RecordingJobsQuery.
        :type: datetime
        """
        
        self._action_date = action_date

    @property
    def integration_id(self):
        """
        Gets the integration_id of this RecordingJobsQuery.
        IntegrationId to Access AWS S3 bucket for bulk recording exports. This field is required and used only for EXPORT action.

        :return: The integration_id of this RecordingJobsQuery.
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """
        Sets the integration_id of this RecordingJobsQuery.
        IntegrationId to Access AWS S3 bucket for bulk recording exports. This field is required and used only for EXPORT action.

        :param integration_id: The integration_id of this RecordingJobsQuery.
        :type: str
        """
        
        self._integration_id = integration_id

    @property
    def include_screen_recordings(self):
        """
        Gets the include_screen_recordings of this RecordingJobsQuery.
        Include Screen recordings for export action, default value = true 

        :return: The include_screen_recordings of this RecordingJobsQuery.
        :rtype: bool
        """
        return self._include_screen_recordings

    @include_screen_recordings.setter
    def include_screen_recordings(self, include_screen_recordings):
        """
        Sets the include_screen_recordings of this RecordingJobsQuery.
        Include Screen recordings for export action, default value = true 

        :param include_screen_recordings: The include_screen_recordings of this RecordingJobsQuery.
        :type: bool
        """
        
        self._include_screen_recordings = include_screen_recordings

    @property
    def conversation_query(self):
        """
        Gets the conversation_query of this RecordingJobsQuery.
        Conversation Query. Note: After the recording is created, it might take up to 48 hours for the recording to be included in the submitted job query.

        :return: The conversation_query of this RecordingJobsQuery.
        :rtype: AsyncConversationQuery
        """
        return self._conversation_query

    @conversation_query.setter
    def conversation_query(self, conversation_query):
        """
        Sets the conversation_query of this RecordingJobsQuery.
        Conversation Query. Note: After the recording is created, it might take up to 48 hours for the recording to be included in the submitted job query.

        :param conversation_query: The conversation_query of this RecordingJobsQuery.
        :type: AsyncConversationQuery
        """
        
        self._conversation_query = conversation_query

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user': 'WfmAgentScheduleUpdateTopicUserReference',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'shifts': 'list[WfmAgentScheduleUpdateTopicWfmScheduleShift]',
            'full_day_time_off_markers': 'list[WfmAgentScheduleUpdateTopicWfmFullDayTimeOffMarker]',
            'updates': 'list[WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdate]'
        }

        self.attribute_map = {
            'user': 'user',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'shifts': 'shifts',
            'full_day_time_off_markers': 'fullDayTimeOffMarkers',
            'updates': 'updates'
        }

        self._user = None
        self._start_date = None
        self._end_date = None
        self._shifts = None
        self._full_day_time_off_markers = None
        self._updates = None

    @property
    def user(self):
        """
        Gets the user of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :return: The user of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :rtype: WfmAgentScheduleUpdateTopicUserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :param user: The user of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :type: WfmAgentScheduleUpdateTopicUserReference
        """
        
        self._user = user

    @property
    def start_date(self):
        """
        Gets the start_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :return: The start_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :param start_date: The start_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :return: The end_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :param end_date: The end_date of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def shifts(self):
        """
        Gets the shifts of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :return: The shifts of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :rtype: list[WfmAgentScheduleUpdateTopicWfmScheduleShift]
        """
        return self._shifts

    @shifts.setter
    def shifts(self, shifts):
        """
        Sets the shifts of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :param shifts: The shifts of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :type: list[WfmAgentScheduleUpdateTopicWfmScheduleShift]
        """
        
        self._shifts = shifts

    @property
    def full_day_time_off_markers(self):
        """
        Gets the full_day_time_off_markers of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :return: The full_day_time_off_markers of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :rtype: list[WfmAgentScheduleUpdateTopicWfmFullDayTimeOffMarker]
        """
        return self._full_day_time_off_markers

    @full_day_time_off_markers.setter
    def full_day_time_off_markers(self, full_day_time_off_markers):
        """
        Sets the full_day_time_off_markers of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :param full_day_time_off_markers: The full_day_time_off_markers of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :type: list[WfmAgentScheduleUpdateTopicWfmFullDayTimeOffMarker]
        """
        
        self._full_day_time_off_markers = full_day_time_off_markers

    @property
    def updates(self):
        """
        Gets the updates of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :return: The updates of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :rtype: list[WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdate]
        """
        return self._updates

    @updates.setter
    def updates(self, updates):
        """
        Sets the updates of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.


        :param updates: The updates of this WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdateNotification.
        :type: list[WfmAgentScheduleUpdateTopicWfmAgentScheduleUpdate]
        """
        
        self._updates = updates

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AnalyticsMediaEndpointStat(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsMediaEndpointStat - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'codecs': 'list[str]',
            'min_mos': 'float',
            'min_r_factor': 'float',
            'max_latency_ms': 'int',
            'received_packets': 'int',
            'invalid_packets': 'int',
            'discarded_packets': 'int',
            'duplicate_packets': 'int',
            'overrun_packets': 'int',
            'underrun_packets': 'int'
        }

        self.attribute_map = {
            'codecs': 'codecs',
            'min_mos': 'minMos',
            'min_r_factor': 'minRFactor',
            'max_latency_ms': 'maxLatencyMs',
            'received_packets': 'receivedPackets',
            'invalid_packets': 'invalidPackets',
            'discarded_packets': 'discardedPackets',
            'duplicate_packets': 'duplicatePackets',
            'overrun_packets': 'overrunPackets',
            'underrun_packets': 'underrunPackets'
        }

        self._codecs = None
        self._min_mos = None
        self._min_r_factor = None
        self._max_latency_ms = None
        self._received_packets = None
        self._invalid_packets = None
        self._discarded_packets = None
        self._duplicate_packets = None
        self._overrun_packets = None
        self._underrun_packets = None

    @property
    def codecs(self):
        """
        Gets the codecs of this AnalyticsMediaEndpointStat.
        The MIME types of the audio encodings used by the audio streams belonging to this endpoint

        :return: The codecs of this AnalyticsMediaEndpointStat.
        :rtype: list[str]
        """
        return self._codecs

    @codecs.setter
    def codecs(self, codecs):
        """
        Sets the codecs of this AnalyticsMediaEndpointStat.
        The MIME types of the audio encodings used by the audio streams belonging to this endpoint

        :param codecs: The codecs of this AnalyticsMediaEndpointStat.
        :type: list[str]
        """
        
        self._codecs = codecs

    @property
    def min_mos(self):
        """
        Gets the min_mos of this AnalyticsMediaEndpointStat.
        The lowest estimated average MOS among all the audio streams belonging to this endpoint

        :return: The min_mos of this AnalyticsMediaEndpointStat.
        :rtype: float
        """
        return self._min_mos

    @min_mos.setter
    def min_mos(self, min_mos):
        """
        Sets the min_mos of this AnalyticsMediaEndpointStat.
        The lowest estimated average MOS among all the audio streams belonging to this endpoint

        :param min_mos: The min_mos of this AnalyticsMediaEndpointStat.
        :type: float
        """
        
        self._min_mos = min_mos

    @property
    def min_r_factor(self):
        """
        Gets the min_r_factor of this AnalyticsMediaEndpointStat.
        The lowest R-factor value among all of the audio streams belonging to this endpoint

        :return: The min_r_factor of this AnalyticsMediaEndpointStat.
        :rtype: float
        """
        return self._min_r_factor

    @min_r_factor.setter
    def min_r_factor(self, min_r_factor):
        """
        Sets the min_r_factor of this AnalyticsMediaEndpointStat.
        The lowest R-factor value among all of the audio streams belonging to this endpoint

        :param min_r_factor: The min_r_factor of this AnalyticsMediaEndpointStat.
        :type: float
        """
        
        self._min_r_factor = min_r_factor

    @property
    def max_latency_ms(self):
        """
        Gets the max_latency_ms of this AnalyticsMediaEndpointStat.
        The maximum latency experienced by any audio stream belonging to this endpoint, in milliseconds

        :return: The max_latency_ms of this AnalyticsMediaEndpointStat.
        :rtype: int
        """
        return self._max_latency_ms

    @max_latency_ms.setter
    def max_latency_ms(self, max_latency_ms):
        """
        Sets the max_latency_ms of this AnalyticsMediaEndpointStat.
        The maximum latency experienced by any audio stream belonging to this endpoint, in milliseconds

        :param max_latency_ms: The max_latency_ms of this AnalyticsMediaEndpointStat.
        :type: int
        """
        
        self._max_latency_ms = max_latency_ms

    @property
    def received_packets(self):
        """
        Gets the received_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received for all audio streams belonging to this endpoint (includes invalid, duplicate, and discarded packets)

        :return: The received_packets of this AnalyticsMediaEndpointStat.
        :rtype: int
        """
        return self._received_packets

    @received_packets.setter
    def received_packets(self, received_packets):
        """
        Sets the received_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received for all audio streams belonging to this endpoint (includes invalid, duplicate, and discarded packets)

        :param received_packets: The received_packets of this AnalyticsMediaEndpointStat.
        :type: int
        """
        
        self._received_packets = received_packets

    @property
    def invalid_packets(self):
        """
        Gets the invalid_packets of this AnalyticsMediaEndpointStat.
        The total number of malformed or not RTP packets, unknown payload type, or discarded probation packets for all audio streams belonging to this endpoint

        :return: The invalid_packets of this AnalyticsMediaEndpointStat.
        :rtype: int
        """
        return self._invalid_packets

    @invalid_packets.setter
    def invalid_packets(self, invalid_packets):
        """
        Sets the invalid_packets of this AnalyticsMediaEndpointStat.
        The total number of malformed or not RTP packets, unknown payload type, or discarded probation packets for all audio streams belonging to this endpoint

        :param invalid_packets: The invalid_packets of this AnalyticsMediaEndpointStat.
        :type: int
        """
        
        self._invalid_packets = invalid_packets

    @property
    def discarded_packets(self):
        """
        Gets the discarded_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received too late or too early, jitter queue overrun or underrun, for all audio streams belonging to this endpoint

        :return: The discarded_packets of this AnalyticsMediaEndpointStat.
        :rtype: int
        """
        return self._discarded_packets

    @discarded_packets.setter
    def discarded_packets(self, discarded_packets):
        """
        Sets the discarded_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received too late or too early, jitter queue overrun or underrun, for all audio streams belonging to this endpoint

        :param discarded_packets: The discarded_packets of this AnalyticsMediaEndpointStat.
        :type: int
        """
        
        self._discarded_packets = discarded_packets

    @property
    def duplicate_packets(self):
        """
        Gets the duplicate_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received with the same sequence number as another one recently received (window of 64 packets), for all audio streams belonging to this endpoint

        :return: The duplicate_packets of this AnalyticsMediaEndpointStat.
        :rtype: int
        """
        return self._duplicate_packets

    @duplicate_packets.setter
    def duplicate_packets(self, duplicate_packets):
        """
        Sets the duplicate_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received with the same sequence number as another one recently received (window of 64 packets), for all audio streams belonging to this endpoint

        :param duplicate_packets: The duplicate_packets of this AnalyticsMediaEndpointStat.
        :type: int
        """
        
        self._duplicate_packets = duplicate_packets

    @property
    def overrun_packets(self):
        """
        Gets the overrun_packets of this AnalyticsMediaEndpointStat.
        The total number of packets for which there was no room in the jitter queue when it was received, for all audio streams belonging to this endpoint (also counted in discarded)

        :return: The overrun_packets of this AnalyticsMediaEndpointStat.
        :rtype: int
        """
        return self._overrun_packets

    @overrun_packets.setter
    def overrun_packets(self, overrun_packets):
        """
        Sets the overrun_packets of this AnalyticsMediaEndpointStat.
        The total number of packets for which there was no room in the jitter queue when it was received, for all audio streams belonging to this endpoint (also counted in discarded)

        :param overrun_packets: The overrun_packets of this AnalyticsMediaEndpointStat.
        :type: int
        """
        
        self._overrun_packets = overrun_packets

    @property
    def underrun_packets(self):
        """
        Gets the underrun_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received after their timestamp/seqnum has been played out, for all audio streams belonging to this endpoint (also counted in discarded)

        :return: The underrun_packets of this AnalyticsMediaEndpointStat.
        :rtype: int
        """
        return self._underrun_packets

    @underrun_packets.setter
    def underrun_packets(self, underrun_packets):
        """
        Sets the underrun_packets of this AnalyticsMediaEndpointStat.
        The total number of packets received after their timestamp/seqnum has been played out, for all audio streams belonging to this endpoint (also counted in discarded)

        :param underrun_packets: The underrun_packets of this AnalyticsMediaEndpointStat.
        :type: int
        """
        
        self._underrun_packets = underrun_packets

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

